pub struct TypstRoot {
pub span: Range<usize>,
pub items: Vec<TypstItem>,
}Expand description
Typst AST root node.
Fields
span: Range<usize>The byte range span of this root node in the source text.
items: Vec<TypstItem>The list of child items in this root node.
Implementations