TypstTokenType

Enum TypstTokenType 

pub enum TypstTokenType {
Show 87 variants Root, Document, Block, Heading, Paragraph, List, ListItem, EnumItem, Table, TableRow, TableCell, Figure, Image, Link, Text, Strong, Emphasis, Code, Math, InlineMath, DisplayMath, Raw, Quote, Script, Expression, FunctionCall, Variable, Assignment, Conditional, Loop, Import, Include, Set, Show, Style, Color, Font, Size, Let, If, Else, For, While, Break, Continue, Return, True, False, Plus, Minus, Star, Slash, Percent, Equal, EqualEqual, NotEqual, Less, Greater, LessEqual, GreaterEqual, And, Or, Not, LeftParen, RightParen, LeftBrace, RightBrace, LeftBracket, RightBracket, Semicolon, Comma, Dot, Colon, Hash, At, Dollar, Underscore, Backtick, StringLiteral, NumericLiteral, Identifier, LineComment, BlockComment, Whitespace, Newline, Eof, Error,
}
Represents the type of a Typst token.

Variants



Root

Root node.



Document

A document.



Block

A block of content.



Heading

A heading (= Heading).



Paragraph

A paragraph of text.



List

A list (+ Item).



ListItem

A list item.



EnumItem

An enumeration item (1. Item).



Table

A table.



TableRow

A table row.



TableCell

A table cell.



Figure

A figure.



Image

An image.

A link.



Text

Plain text.



Strong

Strong text (strong).



Emphasis

Emphasized text (emphasis).



Code

Code content (code).



Math

Math content ($…$).



InlineMath

Inline math content.



DisplayMath

Display math content.



Raw

Raw content.



Quote

A quote.



Script

A script.



Expression

An expression.



FunctionCall

A function call.



Variable

A variable.



Assignment

An assignment.



Conditional

A conditional statement.



Loop

A loop statement.



Import

An import statement.



Include

An include statement.



Set

A set rule.



Show

A show rule.



Style

A style rule.



Color

A color.



Font

A font.



Size

A size.



Let

‘let’ keyword.



If

‘if’ keyword.



Else

‘else’ keyword.



For

‘for’ keyword.



While

‘while’ keyword.



Break

‘break’ keyword.



Continue

‘continue’ keyword.



Return

‘return’ keyword.



True

‘true’ keyword.



False

‘false’ keyword.



Plus

Plus operator (+).



Minus

Minus operator (-).



Star

Multiplication operator (*).



Slash

Division operator (/).



Percent

Modulo operator (%).



Equal

Assignment operator (=).



EqualEqual

Equality operator (==).



NotEqual

Inequality operator (!=).



Less

Less than operator (<).



Greater

Greater than operator (>).



LessEqual

Less than or equal to operator (<=).



GreaterEqual

Greater than or equal to operator (>=).



And

Logical AND operator (and).



Or

Logical OR operator (or).



Not

Logical NOT operator (not).



LeftParen

Left parenthesis (().



RightParen

Right parenthesis ()).



LeftBrace

Left brace ({).



RightBrace

Right brace (}).



LeftBracket

Left bracket ([).



RightBracket

Right bracket (]).



Semicolon

Semicolon separator (;).



Comma

Comma separator (,).



Dot

Dot separator (.).



Colon

Colon separator (:).



Hash

Hash symbol (#).



At

At symbol (@).



Dollar

Dollar symbol ($).



Underscore

Underscore symbol (_).



Backtick

Backtick symbol (`).



StringLiteral

A string literal (“…”).



NumericLiteral

A numeric literal.



Identifier

An identifier.



LineComment

A line comment (// …).



BlockComment

A block comment (/* … */).



Whitespace

Whitespace characters.



Newline

A newline character.



Eof

End of file marker.



Error

Error token.